==> cloudt-boot-starter-mq-3.1.2.7-20230408.135715-1-sources.jar: com/elitescloud/boot/mq/tenant/TenantMessagingOutputInterceptor.java <==
package com.elitescloud.boot.mq.tenant;

import com.elitescloud.cloudt.common.constant.SpringCloudStreamConstant;
import com.elitescloud.cloudt.system.dto.SysTenantDTO;
import com.elitescloud.cloudt.tenant.TenantClient;
import lombok.extern.log4j.Log4j2;
import org.springframework.messaging.Message;
import org.springframework.messaging.MessageChannel;
import org.springframework.messaging.support.ChannelInterceptor;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.messaging.support.MessageHeaderAccessor;

/**
 * 消息发送拦截器.
 *
 * @author Kaiser（wang shao）
 * @date 2022/5/25
 */
@Log4j2
class TenantMessagingOutputInterceptor implements ChannelInterceptor {

    @Override
    public Message<?> preSend(Message<?> message, MessageChannel channel) {
        SysTenantDTO tenant = TenantClient.getSessionTenant();
        if (tenant == null) {
            return message;
        }

        // 判断当前租户，如果租户存在，则传递租户header
        MessageHeaderAccessor headerAccessor = MessageHeaderAccessor.getMutableAccessor(message);
        headerAccessor.setHeaderIfAbsent(SpringCloudStreamConstant.HEADER_TENANT_ID, tenant.getId());

        // 返回消息
        return MessageBuilder.withPayload(message.getPayload())
                .copyHeaders(headerAccessor.getMessageHeaders())
                .build();

    }

    @Override
    public void afterSendCompletion(Message<?> message, MessageChannel channel, boolean sent, Exception ex) {
        if (ex == null) {
            log.info("MQ消息【{}】发送成功，所属租户{}！", () -> message.getHeaders().getId(),
                    () -> message.getHeaders().get(SpringCloudStreamConstant.HEADER_TENANT_ID));
            return;
        }

        log.error("MQ消息发送失败：", ex);
    }
}

==> cloudt-boot-starter-mq-3.2.5.28-20230922.094949-1-sources.jar: com/elitescloud/boot/mq/tenant/TenantMessagingOutputInterceptor.java <==
package com.elitescloud.boot.mq.tenant;

import com.elitescloud.boot.constant.SpringCloudStreamConstant;
import com.elitescloud.boot.tenant.client.common.TenantClient;
import com.elitescloud.cloudt.system.dto.SysTenantDTO;
import lombok.extern.log4j.Log4j2;
import org.springframework.messaging.Message;
import org.springframework.messaging.MessageChannel;
import org.springframework.messaging.support.ChannelInterceptor;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.messaging.support.MessageHeaderAccessor;

/**
 * 消息发送拦截器.
 *
 * @author Kaiser（wang shao）
 * @date 2022/5/25
 */
@Log4j2
class TenantMessagingOutputInterceptor implements ChannelInterceptor {

    @Override
    public Message<?> preSend(Message<?> message, MessageChannel channel) {
        SysTenantDTO tenant = TenantClient.getSessionTenant();
        if (tenant == null) {
            return message;
        }

        // 判断当前租户，如果租户存在，则传递租户header
        MessageHeaderAccessor headerAccessor = MessageHeaderAccessor.getMutableAccessor(message);
        headerAccessor.setHeaderIfAbsent(SpringCloudStreamConstant.HEADER_TENANT_ID, tenant.getId());

        // 返回消息
        return MessageBuilder.withPayload(message.getPayload())
                .copyHeaders(headerAccessor.getMessageHeaders())
                .build();

    }

    @Override
    public void afterSendCompletion(Message<?> message, MessageChannel channel, boolean sent, Exception ex) {
        if (ex == null) {
            log.info("MQ消息【{}】发送成功，所属租户{}！", () -> message.getHeaders().getId(),
                    () -> message.getHeaders().get(SpringCloudStreamConstant.HEADER_TENANT_ID));
            return;
        }

        log.error("MQ消息发送失败：", ex);
    }
}
